<?php
/**
* Enqueue scripts and styles
*
* @package GridView WordPress Theme
* @copyright Copyright (C) 2021 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridview_scripts() {
    global $wp_query;

    wp_enqueue_style('gridview-maincss', get_stylesheet_uri(), array(), NULL);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
    wp_enqueue_style('gridview-webfont', '//fonts.googleapis.com/css?family=Playfair+Display:400,400i,700,700i|Domine:400,700|Oswald:400,700|Roboto+Condensed:400,400i,700,700i&amp;display=swap', array(), NULL);
    wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), NULL, true);

    $gridview_primary_menu_active = FALSE;
    if ( !gridview_get_option('disable_primary_menu') ) {
        $gridview_primary_menu_active = TRUE;
    }
    $gridview_secondary_menu_active = FALSE;
    if ( !gridview_get_option('disable_secondary_menu') ) {
        $gridview_secondary_menu_active = TRUE;
    }

    $gridview_sticky_header_active = FALSE;
    if ( gridview_get_option('enable_sticky_header') ) {
        $gridview_sticky_header_active = TRUE;
    }
    $gridview_sticky_header_mobile_active = FALSE;
    if ( gridview_get_option('enable_sticky_mobile_header') ) {
        $gridview_sticky_header_mobile_active = TRUE;
    }

    $gridview_sticky_sidebar_active = TRUE;
    if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
       $gridview_sticky_sidebar_active = FALSE;
    }
    if ( is_404() ) {
        $gridview_sticky_sidebar_active = FALSE;
    }
    if ( $gridview_sticky_sidebar_active ) {
        wp_enqueue_script('ResizeSensor', get_template_directory_uri() .'/assets/js/ResizeSensor.min.js', array( 'jquery' ), NULL, true);
        wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.min.js', array( 'jquery' ), NULL, true);
    }

    $gridview_columnwidth = '.'.gridview_post_grid_cols().'-sizer';
    $gridview_gutter = '.'.gridview_post_grid_cols().'-gutter';

    wp_enqueue_script('gridview-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), NULL, true );
    wp_enqueue_script('gridview-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), NULL, true );
    wp_enqueue_script('gridview-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded', 'masonry' ), NULL, true);

    wp_localize_script( 'gridview-customjs', 'gridview_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $gridview_primary_menu_active,
            'secondary_menu_active' => $gridview_secondary_menu_active,
            'sticky_header_active' => $gridview_sticky_header_active,
            'sticky_header_mobile_active' => $gridview_sticky_header_mobile_active,
            'sticky_sidebar_active' => $gridview_sticky_sidebar_active,
            'columnwidth' => $gridview_columnwidth,
            'gutter' => $gridview_gutter,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('gridview-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), NULL, true);

    wp_localize_script('gridview-html5shiv-js','gridview_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'gridview'),
    ));
}
add_action( 'wp_enqueue_scripts', 'gridview_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function gridview_ie_scripts() {
    wp_enqueue_script( 'html5shiv', get_template_directory_uri(). '/assets/js/html5shiv.min.js', array(), NULL, false);
    wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), NULL, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'gridview_ie_scripts' );

/**
 * Enqueue customizer styles.
 */
function gridview_enqueue_customizer_styles() {
    wp_enqueue_style( 'gridview-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), NULL );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
}
add_action( 'customize_controls_enqueue_scripts', 'gridview_enqueue_customizer_styles' );