<?php
/**
* More Custom Functions
*
* @package GridView WordPress Theme
* @copyright Copyright (C) 2021 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function gridview_pingback_header() {
    if ( is_singular() && pings_open() ) {
            echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'gridview_pingback_header' );

function gridview_read_more_text() {
   $readmoretext = esc_html__( 'read more', 'gridview' );
    if ( gridview_get_option('read_more_text') ) {
            $readmoretext = gridview_get_option('read_more_text');
    }
   return apply_filters( 'gridview_read_more_text', $readmoretext );
}

// Change excerpt length
function gridview_excerpt_length($length) {
    if ( is_admin() ) {
        return $length;
    }
    $read_more_length = 20;
    if ( gridview_get_option('read_more_length') ) {
        $read_more_length = gridview_get_option('read_more_length');
    }
    return apply_filters( 'gridview_excerpt_length', $read_more_length );
}
add_filter('excerpt_length', 'gridview_excerpt_length');

// Change excerpt more word
function gridview_excerpt_more($more) {
    if ( is_admin() ) {
     return $more;
    }
    global $post;
    if ( gridview_get_option('hide_read_more_button') ) {
        return '...';
    } else {
        return '... <span class="gridview-grid-post-read-more"><a href="'.esc_url( get_permalink() ).'">'.esc_html( gridview_read_more_text() ).'<span class="gridview-sr-only"> '.wp_kses_post( get_the_title() ).'</span></a></span>';
    }
}
add_filter('excerpt_more', 'gridview_excerpt_more');


if ( ! function_exists( 'wp_body_open' ) ) :
    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     */
    function wp_body_open() { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
        /**
         * Triggered after the opening <body> tag.
         */
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
endif;